@@ -11,7 +11,7 @@ use crate::{
     common::{
         ende::encode_optioned_bytes, BranchID, BranchName, RawKey, RawValue, VersionID,
         VersionName, BRANCH_ANCESTORS_LIMIT, INITIAL_BRANCH_ID, INITIAL_BRANCH_NAME,
-        NULL, VSDB,
+        INITIAL_VERSION, NULL, VSDB,
     },
 };
 use ruc::*;
@@ -73,6 +73,7 @@ impl MapxRawVs {
         self.branch_to_parent.insert(INITIAL_BRANCH_ID, None);
         self.branch_to_created_versions
             .insert(INITIAL_BRANCH_ID, MapxOrd::new());
+        self.version_create(INITIAL_VERSION.0).unwrap();
     }
 
     #[inline(always)]
